@@ -22,7 +22,9 @@ __all__ = (
     "GetRecommendationsResponseTypeDef",
 )
 
-PredictedItemTypeDef = TypedDict("PredictedItemTypeDef", {"itemId": str}, total=False)
+PredictedItemTypeDef = TypedDict(
+    "PredictedItemTypeDef", {"itemId": str, "score": float}, total=False
+)
 
 GetPersonalizedRankingResponseTypeDef = TypedDict(
     "GetPersonalizedRankingResponseTypeDef",
